package
Version:
v0.0.0-...-ffad6be
Opens a new window with list of versions in this module.
Published: Sep 9, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Metadata struct {
Hostname string `json:"hostname"`
AppName string `json:"app_name"`
AppVersion string `json:"app_version"`
Env string `json:"env"`
Uptime time.Duration `json:"uptime"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.